// Detect browser type
const isEdge = navigator.userAgent.includes("Edg/");
const isChrome = navigator.userAgent.includes("Chrome/") && !isEdge;

// Track microphone permission state
let microphonePermissionGranted = false;

// Open the chat interface when extension icon is clicked
chrome.action.onClicked.addListener(async (tab) => {
  console.log('Extension icon clicked');
  // Toggle the side panel
  await chrome.sidePanel.open({ windowId: tab.windowId });
  await chrome.sidePanel.setOptions({
    enabled: true,
    path: 'index.html'
  });
});

// Set initial state when extension is installed
chrome.runtime.onInstalled.addListener((details) => {
  console.log('Extension installed/updated:', details.reason);

  if (details.reason === 'install') {
    console.log('Setting up initial preferences...');
    // Set initial preferences
    const defaultPreferences = {
      username: `User${Math.floor(Math.random() * 1000)}`,
      theme: 'light',
      notifications: true,
      avatar: '',
      color: '#6366f1'
    };

    chrome.storage.local.set({ 
      preferences: defaultPreferences,
      installationComplete: false, // Show installation wizard on first load
      microphonePermissionGranted: false
    }, () => {
      console.log('Initial preferences set');
      // Request microphone permission on install
      requestMicrophonePermission();
    });
  }
});

// Function to request microphone permission
async function requestMicrophonePermission() {
  console.log('Requesting microphone permission...');

  try {
    if (chrome.permissions) {
      const result = await chrome.permissions.request({
        permissions: ['microphone']
      });
      console.log('Microphone permission request result:', result);
      microphonePermissionGranted = result;

      // Store the permission state
      chrome.storage.local.set({ microphonePermissionGranted: result });
      return result;
    }
  } catch (error) {
    console.error('Error requesting microphone permission:', error);
    return false;
  }
}

// Check if microphone permission is granted
async function checkMicrophonePermission() {
  console.log('Checking microphone permission...');

  try {
    if (chrome.permissions) {
      const result = await chrome.permissions.contains({
        permissions: ['microphone']
      });
      console.log('Current microphone permission state:', result);
      return result;
    }
  } catch (error) {
    console.error('Error checking microphone permission:', error);
  }
  return false;
}

// Listen for microphone permission requests from the side panel
chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
  console.log('Received message:', request);

  if (request.type === 'REQUEST_MICROPHONE') {
    console.log('Processing microphone permission request...');

    // First check if we already have permission
    checkMicrophonePermission().then(hasPermission => {
      if (hasPermission) {
        console.log('Microphone permission already granted');
        sendResponse({ granted: true });
      } else {
        // Request new permission
        requestMicrophonePermission().then(granted => {
          console.log('New microphone permission request result:', granted);
          sendResponse({ granted });
        });
      }
    });

    return true; // Keep the message channel open for async response
  }

  if (request.type === 'CHECK_MICROPHONE_PERMISSION') {
    console.log('Checking current microphone permission...');

    checkMicrophonePermission().then(hasPermission => {
      console.log('Current permission state:', hasPermission);
      sendResponse({ granted: hasPermission });
    });

    return true; // Keep the message channel open for async response
  }
});

// Handle browser-specific initialization
if (isEdge) {
  console.log("Running in Microsoft Edge");
} else if (isChrome) {
  console.log("Running in Google Chrome");
}

// Log any permission changes
chrome.permissions.onAdded.addListener((permissions) => {
  console.log('Permissions added:', permissions);
});

chrome.permissions.onRemoved.addListener((permissions) => {
  console.log('Permissions removed:', permissions);
});